@@ -1,28 +1,28 @@
 import time
-
-from test_Base import TestBase
-
 import logging
+
+from aperturedb.Connector import Connector
+
 logger = logging.getLogger(__name__)
 
 
-class TestSession(TestBase):
+class TestSession():
 
     '''
         These check operation of the Connector Session
     '''
 
-    def test_sessionRenew(self):
+    def test_sessionRenew(self, db: Connector):
         '''
             Verifies that Session renew works
         '''
 
         try:
-            db = self.create_connection()
             # force session token expiry
             db.shared_data.session.session_token_ttl = 1
             logging.debug("Connected? {0}".format(
                 "yes" if db.connected else "no"))
+
             logging.debug(
                 "Session valid? {0}".format(
                     "yes" if db.shared_data.session.valid() else "no"))
@@ -38,7 +38,8 @@ class TestSession(TestBase):
             }]
             responses, blobs = db.query(query)
             logging.debug(responses)
-            self.assertTrue(db.shared_data.session.valid(),
-                            "Failed to renew Session")
-        except Exception:
-            self.fail("Failed to renew Session")
+            assert db.shared_data.session.valid() == True
+        except Exception as e:
+            print(e)
+            print("Failed to renew Session")
+            assert False
